# Generated by Django 4.0.3 on 2022-04-05 14:12

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('EmailTemplate', '0004_auto_20210226_0911'),
    ]

    operations = [
        migrations.AddField(
            model_name='emailtemplate',
            name='bcc',
            field=models.CharField(blank=True, max_length=1000, null=True, verbose_name='BCC'),
        ),
        migrations.AddField(
            model_name='emailtemplate',
            name='cc',
            field=models.CharField(blank=True, max_length=1000, null=True, verbose_name='CC'),
        ),
    ]
