# Generated by Django 3.1.6 on 2021-02-26 09:11

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('EmailTemplate', '0003_auto_20190719_1358'),
    ]

    operations = [
        migrations.AlterField(
            model_name='emailtemplate',
            name='to_email',
            field=models.CharField(blank=True, max_length=1000, null=True, verbose_name='To'),
        ),
    ]
