# Generated by Django 2.1.3 on 2019-01-10 21:51

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='EmailTemplate',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('template_key', models.CharField(max_length=255, unique=True, verbose_name='Key')),
                ('subject', models.CharField(blank=True, max_length=255, null=True, verbose_name='Subject')),
                ('to_email', models.CharField(blank=True, max_length=255, null=True, verbose_name='To')),
                ('from_email', models.CharField(blank=True, max_length=255, null=True, verbose_name='From')),
                ('html_template', models.TextField(blank=True, null=True, verbose_name='HTML')),
                ('plain_text', models.TextField(blank=True, null=True, verbose_name='Plain')),
                ('is_html', models.BooleanField(default=False, verbose_name='Is HTML?')),
                ('is_text', models.BooleanField(default=False, verbose_name='Is Text?')),
            ],
        ),
    ]
